@@ -1,4 +1,4 @@
-## ---- include=FALSE---------------------------------------------------------------------------------------------------
+## ----include=FALSE----------------------------------------------------------------------------------------------------
 knitr::opts_chunk$set(fig.width=4.5, fig.height=4)
 
 ## ----include=FALSE----------------------------------------------------------------------------------------------------
@@ -49,19 +49,25 @@ Plot(x, y, transparency=0.95)
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(x, y, n_bins=5)
 
-## ---- fig.height=2.75-------------------------------------------------------------------------------------------------
+## ----fig.height=2.75--------------------------------------------------------------------------------------------------
 Plot(Salary)
 
-## ---- fig.height=2.75-------------------------------------------------------------------------------------------------
+## ----fig.height=2.75--------------------------------------------------------------------------------------------------
 Plot(Salary, vbs_plot="b")
 
-## ---- fig.height=5.5, fig.width=5.5-----------------------------------------------------------------------------------
+## ----fig.height=2.75--------------------------------------------------------------------------------------------------
+
+
+## ----fig.height=2.75--------------------------------------------------------------------------------------------------
+Plot(Salary, stat_x="%", bin_width=13000)
+
+## ----fig.height=5.5, fig.width=5.5------------------------------------------------------------------------------------
 Plot(Salary, row_names)
 
-## ---- fig.height=5.75, fig.width=5.5----------------------------------------------------------------------------------
+## ----fig.height=5.75, fig.width=5.5-----------------------------------------------------------------------------------
 Plot(Salary, row_names, sort_yx="0", segments_y=FALSE)
 
-## ---- fig.height=5.75, fig.width=6.0----------------------------------------------------------------------------------
+## ----fig.height=5.75, fig.width=6.0-----------------------------------------------------------------------------------
 Plot(c(Pre, Post), row_names)
 
 ## ----by, fig.width=6--------------------------------------------------------------------------------------------------
@@ -73,31 +79,34 @@ Plot(Years, Salary, by=Gender, size=2, fit="lm",
      color=c("darkgreen", "gold4")
 )
 
-## ---- fig.width=5, fig.height=3.5-------------------------------------------------------------------------------------
+## ----varfy, fig.width=6-----------------------------------------------------------------------------------------------
+Plot(Years, Salary, by=Gender, shape="vary")
+
+## ----fig.width=5, fig.height=3.5--------------------------------------------------------------------------------------
 Plot(Years, Salary, by1=Gender, fit="lm")
 
 ## ---------------------------------------------------------------------------------------------------------------------
 Plot(Salary, Dept)
 
-## ---- fig.width=5, fig.height=2.75------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=2.75-------------------------------------------------------------------------------------
 Plot(Salary, by=Gender)
 
-## ---- fig.width=5, fig.height=2.75------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=2.75-------------------------------------------------------------------------------------
 Plot(Salary, by1=Gender)
 
-## ---- fig.width=5, fig.height=2.75------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=2.75-------------------------------------------------------------------------------------
 Plot(Salary, by1=Gender, vbs_plot="vs")
 
-## ---- fig.width=5, fig.height=2.75------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=2.75-------------------------------------------------------------------------------------
 BoxPlot(Salary, by1=Gender, vbs_mean=TRUE, box_fill="lightgoldenrod")
 
-## ---- fig.width=6-----------------------------------------------------------------------------------------------------
+## ----fig.width=6------------------------------------------------------------------------------------------------------
 Plot(Salary, Dept, by=Gender)
 
-## ---- fig.width=5, fig.height=7---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=7----------------------------------------------------------------------------------------
 Plot(Salary, by1=Gender, by2=Dept, n_col=1)
 
-## ---- fig.width=5, fig.height=5---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=5----------------------------------------------------------------------------------------
 Plot(Salary, by1=Dept, by=Gender, n_col=1)
 
 ## ---------------------------------------------------------------------------------------------------------------------
@@ -107,19 +116,19 @@ d <- Read("Cars93")
 d$Transmission <- factor(d$Manual, levels=0:1, labels=c("Auto", "Manual"))
 d$Source <- factor(d$Source, levels=0:1, labels=c("Foreign", "Domestic"))
 
-## ---- fig.height=7, fig.width=6---------------------------------------------------------------------------------------
+## ----fig.height=7, fig.width=6----------------------------------------------------------------------------------------
 Plot(Weight, MPGcity, by1=Cylinders, by2=Transmission, by=Source, n_col=1)
 
-## ---- fig.height=3----------------------------------------------------------------------------------------------------
+## ----fig.height=3-----------------------------------------------------------------------------------------------------
 d <- Read("Employee", quiet=TRUE)
 Plot(Dept, Gender)
 
-## ---- fig.height=3.5, fig.width=6-------------------------------------------------------------------------------------
+## ----fig.height=3.5, fig.width=6--------------------------------------------------------------------------------------
 Plot(Dept, Gender, radius=.6, power=0.8, pad_x=0.05, pad_y=0.05)
 
-## ---- fig.height=3----------------------------------------------------------------------------------------------------
+## ----fig.height=3-----------------------------------------------------------------------------------------------------
 Plot(Dept, by1=Gender)
 
-## ---- fig.height=2.5--------------------------------------------------------------------------------------------------
+## ----fig.height=2.5---------------------------------------------------------------------------------------------------
 Plot(Dept)
 
