@@ -14,7 +14,7 @@ reg_brief(Salary ~ Years + Pre)
 ## ---------------------------------------------------------------------------------------------------------------------
 reg(Salary ~ Years + Pre)
 
-## ---- fig.width=4.5, fig.height=4-------------------------------------------------------------------------------------
+## ----fig.width=4.5, fig.height=4--------------------------------------------------------------------------------------
 reg_brief(Salary ~ Years, new_scale="z", plot_errors=TRUE)
 
 ## ---------------------------------------------------------------------------------------------------------------------
@@ -46,8 +46,8 @@ cnt <- contr.sum(n=3)
 cnt
 
 ## ----fig.width=4.5, fig.height=4--------------------------------------------------------------------------------------
-d$Plan <- factor(d$Plan)
-reg_brief(Salary ~ Plan, contrasts=list(Plan=cnt))
+d$JobSat <- factor(d$JobSat, levels=c("low", "med", "high"))
+reg_brief(Salary ~ JobSat, contrasts=list(JobSat=cnt))
 
 ## ----fig.width=5------------------------------------------------------------------------------------------------------
 reg_brief(Salary ~ 1, plot_errors=TRUE)
@@ -56,23 +56,23 @@ reg_brief(Salary ~ 1, plot_errors=TRUE)
 dd <- Read("Mach4")
 reg_brief(m10 ~ m02, data=dd)
 
-## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=4----------------------------------------------------------------------------------------
 Plot(Salary, Years, by=Dept, fit="lm")
 
-## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=4----------------------------------------------------------------------------------------
 reg_brief(Salary ~ Dept + Years)
 
 ## ----mod, fig.width=4.5, fig.height=4.5-------------------------------------------------------------------------------
 reg_brief(Salary ~ Years + Pre, mod=Pre)
 
-## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=4----------------------------------------------------------------------------------------
 d <- Read("BodyMeas")
 Logit(Gender ~ Hand)
 
-## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=4----------------------------------------------------------------------------------------
 Logit(Gender ~ Hand, prob_cut=c(.3, .5, .7))
 
-## ---- fig.width=5, fig.height=4---------------------------------------------------------------------------------------
+## ----fig.width=5, fig.height=4----------------------------------------------------------------------------------------
 d$Gender <- ifelse (d$Gender == "M", 1, 0)
 Plot(Hand, Gender, n_bins=6)
 
